api.documents.v1 package — Argus-Toolbelt 1.0 documentation

# api.documents.v1 package

## Subpackages

- api.documents.v1.customer package
  - Submodules
  - api.documents.v1.customer.customer module
  - Module contents
- api.documents.v1.document package
  - Submodules
  - api.documents.v1.document.document module
  - Module contents
- api.documents.v1.folder package
  - Submodules
  - api.documents.v1.folder.folder_root module
  - Module contents

## Module contents